@@ -1,10 +1,14 @@
 //! Rust packages enumerated in `Cargo.lock`
 
-pub mod checksum;
-pub mod name;
-pub mod source;
+mod checksum;
+mod name;
+mod source;
 
-pub use self::{checksum::Checksum, name::Name, source::SourceId};
+pub use self::{
+    checksum::Checksum,
+    name::Name,
+    source::{GitReference, SourceId, SourceKind},
+};
 pub use semver::Version;
 
 use crate::dependency::Dependency;
